} // end namespace internal
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_MATHFUNCTIONS_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Solve.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Solve.h
index ba2ee53b8..964b9a0af 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Solve.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Solve.h
@@ -10,7 +10,7 @@
#ifndef EIGEN_SOLVE_H
#define EIGEN_SOLVE_H
-namespace Eigen {
+namespace StormEigen {
template
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Matrix.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Matrix.h
index ce1b70d23..3c6e924d9 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Matrix.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Matrix.h
@@ -11,7 +11,7 @@
#ifndef EIGEN_MATRIX_H
#define EIGEN_MATRIX_H
-namespace Eigen {
+namespace StormEigen {
/** \class Matrix
* \ingroup Core_Module
@@ -54,13 +54,13 @@ namespace Eigen {
* You can access elements of vectors and matrices using normal subscripting:
*
* \code
- * Eigen::VectorXd v(10);
+ * StormEigen::VectorXd v(10);
* v[0] = 0.1;
* v[1] = 0.2;
* v(0) = 0.3;
* v(1) = 0.4;
*
- * Eigen::MatrixXi m(10, 10);
+ * StormEigen::MatrixXi m(10, 10);
* m(0, 1) = 1;
* m(0, 2) = 2;
* m(0, 3) = 3;
@@ -105,7 +105,7 @@ namespace Eigen {
* \code Matrix \endcode | \code
* struct {
* T *data; // with (size_t(data)%EIGEN_MAX_ALIGN_BYTES)==0
- * Eigen::Index rows, cols;
+ * StormEigen::Index rows, cols;
* };
* \endcode |
* \code
@@ -113,7 +113,7 @@ namespace Eigen {
* Matrix \endcode | \code
* struct {
* T *data; // with (size_t(data)%EIGEN_MAX_ALIGN_BYTES)==0
- * Eigen::Index size;
+ * StormEigen::Index size;
* };
* \endcode |
* \code Matrix \endcode | \code
@@ -124,7 +124,7 @@ namespace Eigen {
* |
\code Matrix \endcode | \code
* struct {
* T data[MaxRows*MaxCols]; // with (size_t(data)%A(MaxRows*MaxCols*sizeof(T)))==0
- * Eigen::Index rows, cols;
+ * StormEigen::Index rows, cols;
* };
* \endcode |
*
@@ -155,7 +155,7 @@ private:
public:
typedef _Scalar Scalar;
typedef Dense StorageKind;
- typedef Eigen::Index StorageIndex;
+ typedef StormEigen::Index StorageIndex;
typedef MatrixXpr XprKind;
enum {
RowsAtCompileTime = _Rows,
@@ -456,6 +456,6 @@ EIGEN_MAKE_TYPEDEFS_ALL_SIZES(std::complex, cd)
#undef EIGEN_MAKE_TYPEDEFS
#undef EIGEN_MAKE_FIXED_TYPEDEFS
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_MATRIX_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/MatrixBase.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/MatrixBase.h
index 9d612c852..010d95ca5 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/MatrixBase.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/MatrixBase.h
@@ -11,7 +11,7 @@
#ifndef EIGEN_MATRIXBASE_H
#define EIGEN_MATRIXBASE_H
-namespace Eigen {
+namespace StormEigen {
/** \class MatrixBase
* \ingroup Core_Module
@@ -34,7 +34,7 @@ namespace Eigen {
*
* \code
template
- void printFirstRow(const Eigen::MatrixBase& x)
+ void printFirstRow(const StormEigen::MatrixBase& x)
{
cout << x.row(0) << endl;
}
@@ -122,7 +122,7 @@ template class MatrixBase
internal::traits::ColsAtCompileTime> BasisReturnType;
#endif // not EIGEN_PARSED_BY_DOXYGEN
-#define EIGEN_CURRENT_STORAGE_BASE_CLASS Eigen::MatrixBase
+#define EIGEN_CURRENT_STORAGE_BASE_CLASS StormEigen::MatrixBase
# include "../plugins/CommonCwiseUnaryOps.h"
# include "../plugins/CommonCwiseBinaryOps.h"
# include "../plugins/MatrixCwiseUnaryOps.h"
@@ -303,7 +303,7 @@ template class MatrixBase
inline bool operator!=(const MatrixBase& other) const
{ return cwiseNotEqual(other).any(); }
- NoAlias noalias();
+ NoAlias noalias();
// TODO forceAlignedAccess is temporarily disabled
// Need to find a nicer workaround.
@@ -319,10 +319,10 @@ template class MatrixBase
EIGEN_DEVICE_FUNC MatrixBase& matrix() { return *this; }
EIGEN_DEVICE_FUNC const MatrixBase& matrix() const { return *this; }
/** \returns an \link Eigen::ArrayBase Array \endlink expression of this matrix
* \sa ArrayBase::matrix() */
EIGEN_DEVICE_FUNC EIGEN_STRONG_INLINE ArrayWrapper array() { return ArrayWrapper(derived()); }
/** \returns a const \link Eigen::ArrayBase Array \endlink expression of this matrix
* \sa ArrayBase::matrix() */
EIGEN_DEVICE_FUNC EIGEN_STRONG_INLINE const ArrayWrapper array() const { return ArrayWrapper(derived()); }
@@ -522,6 +522,6 @@ inline void MatrixBase::applyOnTheLeft(const EigenBase &o
other.derived().applyThisOnTheLeft(derived());
}
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_MATRIXBASE_H
@@ -319,10 +319,10 @@ template class MatrixBase
EIGEN_DEVICE_FUNC MatrixBase& matrix() { return *this; }
EIGEN_DEVICE_FUNC const MatrixBase& matrix() const { return *this; }
- /** \returns an \link Eigen::ArrayBase Array \endlink expression of this matrix
+ /** \returns an \link StormEigen::ArrayBase Array \endlink expression of this matrix
* \sa ArrayBase::matrix() */
EIGEN_DEVICE_FUNC EIGEN_STRONG_INLINE ArrayWrapper array() { return ArrayWrapper(derived()); }
@@ -319,10 +319,10 @@ template class MatrixBase
* \sa ArrayBase::matrix() */
EIGEN_DEVICE_FUNC EIGEN_STRONG_INLINE ArrayWrapper array() { return ArrayWrapper(derived()); }
- /** \returns a const \link Eigen::ArrayBase Array \endlink expression of this matrix
+ /** \returns a const \link StormEigen::ArrayBase Array \endlink expression of this matrix
* \sa ArrayBase::matrix() */
EIGEN_DEVICE_FUNC EIGEN_STRONG_INLINE const ArrayWrapper array() const { return ArrayWrapper(derived()); }
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NestByValue.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NestByValue.h
index 9aeaf8d18..98a15cf51 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NestByValue.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NestByValue.h
@@ -11,7 +11,7 @@
#ifndef EIGEN_NESTBYVALUE_H
#define EIGEN_NESTBYVALUE_H
-namespace Eigen {
+namespace StormEigen {
/** \class NestByValue
* \ingroup Core_Module
@@ -106,6 +106,6 @@ DenseBase::nestByValue() const
return NestByValue(derived());
}
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_NESTBYVALUE_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NoAlias.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NoAlias.h
index 0ade75255..30a70e1ae 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NoAlias.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NoAlias.h
@@ -10,7 +10,7 @@
#ifndef EIGEN_NOALIAS_H
#define EIGEN_NOALIAS_H
-namespace Eigen {
+namespace StormEigen {
/** \class NoAlias
* \ingroup Core_Module
@@ -100,9 +100,9 @@ class NoAlias
template
NoAlias MatrixBase::noalias()
{
- return NoAlias(derived());
+ return NoAlias(derived());
}
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_NOALIAS_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NumTraits.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NumTraits.h
index 1d85dec72..7f475b306 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NumTraits.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/NumTraits.h
@@ -10,7 +10,7 @@
#ifndef EIGEN_NUMTRAITS_H
#define EIGEN_NUMTRAITS_H
-namespace Eigen {
+namespace StormEigen {
/** \class NumTraits
* \ingroup Core_Module
@@ -166,6 +166,6 @@ struct NumTraits >
static inline RealScalar dummy_precision() { return NumTraits::dummy_precision(); }
};
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_NUMTRAITS_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/PermutationMatrix.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/PermutationMatrix.h
index 90e1df233..56981c17f 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/PermutationMatrix.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/PermutationMatrix.h
@@ -11,7 +11,7 @@
#ifndef EIGEN_PERMUTATIONMATRIX_H
#define EIGEN_PERMUTATIONMATRIX_H
-namespace Eigen {
+namespace StormEigen {
/** \class PermutationBase
* \ingroup Core_Module
@@ -631,6 +631,6 @@ template<> struct AssignmentKind { typedef EigenBas
} // end namespace internal
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_PERMUTATIONMATRIX_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/PlainObjectBase.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/PlainObjectBase.h
index 1225e85b4..ec42f2078 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/PlainObjectBase.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/PlainObjectBase.h
@@ -22,7 +22,7 @@
# define EIGEN_INITIALIZE_COEFFS_IF_THAT_OPTION_IS_ENABLED
#endif
-namespace Eigen {
+namespace StormEigen {
namespace internal {
@@ -111,22 +111,22 @@ class PlainObjectBase : public internal::dense_xpr_base::type
using Base::IsVectorAtCompileTime;
using Base::Flags;
- template friend class Eigen::Map;
- friend class Eigen::Map;
- typedef Eigen::Map MapType;
- friend class Eigen::Map;
- typedef const Eigen::Map ConstMapType;
+ template friend class StormEigen::Map;
+ friend class StormEigen::Map;
+ typedef StormEigen::Map MapType;
+ friend class StormEigen::Map;
+ typedef const StormEigen::Map ConstMapType;
#if EIGEN_MAX_ALIGN_BYTES>0
// for EIGEN_MAX_ALIGN_BYTES==0, AlignedMax==Unaligned, and many compilers generate warnings for friend-ing a class twice.
- friend class Eigen::Map;
- friend class Eigen::Map;
+ friend class StormEigen::Map;
+ friend class StormEigen::Map;
#endif
- typedef Eigen::Map AlignedMapType;
- typedef const Eigen::Map ConstAlignedMapType;
- template struct StridedMapType { typedef Eigen::Map type; };
- template struct StridedConstMapType { typedef Eigen::Map type; };
- template struct StridedAlignedMapType { typedef Eigen::Map type; };
- template struct StridedConstAlignedMapType { typedef Eigen::Map type; };
+ typedef StormEigen::Map AlignedMapType;
+ typedef const StormEigen::Map ConstAlignedMapType;
+ template struct StridedMapType { typedef StormEigen::Map type; };
+ template struct StridedConstMapType { typedef StormEigen::Map type; };
+ template struct StridedAlignedMapType { typedef StormEigen::Map type; };
+ template struct StridedConstAlignedMapType { typedef StormEigen::Map type; };
protected:
DenseStorage m_storage;
@@ -989,6 +989,6 @@ struct matrix_swap_impl
} // end namespace internal
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_DENSESTORAGEBASE_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Product.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Product.h
index fdd2fed3f..fb50926ab 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Product.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Product.h
@@ -10,7 +10,7 @@
#ifndef EIGEN_PRODUCT_H
#define EIGEN_PRODUCT_H
-namespace Eigen {
+namespace StormEigen {
template class ProductImpl;
@@ -217,6 +217,6 @@ class ProductImpl
};
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_PRODUCT_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/ProductEvaluators.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/ProductEvaluators.h
index 794038a2a..e38804644 100755
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/ProductEvaluators.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/ProductEvaluators.h
@@ -13,7 +13,7 @@
#ifndef EIGEN_PRODUCTEVALUATORS_H
#define EIGEN_PRODUCTEVALUATORS_H
-namespace Eigen {
+namespace StormEigen {
namespace internal {
@@ -1056,6 +1056,6 @@ struct generic_product_impl, MatrixShape, TranspositionsShap
} // end namespace internal
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_PRODUCT_EVALUATORS_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Random.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Random.h
index 02038e9e3..b9c380723 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Random.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Random.h
@@ -10,7 +10,7 @@
#ifndef EIGEN_RANDOM_H
#define EIGEN_RANDOM_H
-namespace Eigen {
+namespace StormEigen {
namespace internal {
@@ -178,6 +178,6 @@ PlainObjectBase::setRandom(Index rows, Index cols)
return setRandom();
}
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_RANDOM_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Redux.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Redux.h
index d170cae29..3d3881eff 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Redux.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Redux.h
@@ -11,7 +11,7 @@
#ifndef EIGEN_REDUX_H
#define EIGEN_REDUX_H
-namespace Eigen {
+namespace StormEigen {
namespace internal {
@@ -423,7 +423,7 @@ template
EIGEN_STRONG_INLINE typename internal::traits::Scalar
DenseBase::minCoeff() const
{
- return derived().redux(Eigen::internal::scalar_min_op());
+ return derived().redux(StormEigen::internal::scalar_min_op());
}
/** \returns the maximum of all coefficients of \c *this.
@@ -433,7 +433,7 @@ template
EIGEN_STRONG_INLINE typename internal::traits::Scalar
DenseBase::maxCoeff() const
{
- return derived().redux(Eigen::internal::scalar_max_op());
+ return derived().redux(StormEigen::internal::scalar_max_op());
}
/** \returns the sum of all coefficients of *this
@@ -446,7 +446,7 @@ DenseBase::sum() const
{
if(SizeAtCompileTime==0 || (SizeAtCompileTime==Dynamic && size()==0))
return Scalar(0);
- return derived().redux(Eigen::internal::scalar_sum_op());
+ return derived().redux(StormEigen::internal::scalar_sum_op());
}
/** \returns the mean of all coefficients of *this
@@ -457,7 +457,7 @@ template
EIGEN_STRONG_INLINE typename internal::traits::Scalar
DenseBase::mean() const
{
- return Scalar(derived().redux(Eigen::internal::scalar_sum_op())) / Scalar(this->size());
+ return Scalar(derived().redux(StormEigen::internal::scalar_sum_op())) / Scalar(this->size());
}
/** \returns the product of all coefficients of *this
@@ -473,7 +473,7 @@ DenseBase::prod() const
{
if(SizeAtCompileTime==0 || (SizeAtCompileTime==Dynamic && size()==0))
return Scalar(1);
- return derived().redux(Eigen::internal::scalar_product_op());
+ return derived().redux(StormEigen::internal::scalar_product_op());
}
/** \returns the trace of \c *this, i.e. the sum of the coefficients on the main diagonal.
@@ -489,6 +489,6 @@ MatrixBase::trace() const
return derived().diagonal().sum();
}
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_REDUX_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Ref.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Ref.h
index 61de5ed17..951e23d62 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Ref.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Ref.h
@@ -10,7 +10,7 @@
#ifndef EIGEN_REF_H
#define EIGEN_REF_H
-namespace Eigen {
+namespace StormEigen {
/** \class Ref
* \ingroup Core_Module
@@ -271,6 +271,6 @@ template class Ref<
TPlainObjectType m_object;
};
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_REF_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Replicate.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Replicate.h
index bec598310..7fb5bb37a 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Replicate.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Replicate.h
@@ -10,7 +10,7 @@
#ifndef EIGEN_REPLICATE_H
#define EIGEN_REPLICATE_H
-namespace Eigen {
+namespace StormEigen {
/**
* \class Replicate
@@ -136,6 +136,6 @@ VectorwiseOp::replicate(Index factor) const
(_expression(),Direction==Vertical?factor:1,Direction==Horizontal?factor:1);
}
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_REPLICATE_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/ReturnByValue.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/ReturnByValue.h
index 7feb6e01c..ff87ecde8 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/ReturnByValue.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/ReturnByValue.h
@@ -11,7 +11,7 @@
#ifndef EIGEN_RETURNBYVALUE_H
#define EIGEN_RETURNBYVALUE_H
-namespace Eigen {
+namespace StormEigen {
/** \class ReturnByValue
* \ingroup Core_Module
@@ -113,6 +113,6 @@ protected:
} // end namespace internal
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_RETURNBYVALUE_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Reverse.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Reverse.h
index d7c380c78..c5db38ae9 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Reverse.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Reverse.h
@@ -12,7 +12,7 @@
#ifndef EIGEN_REVERSE_H
#define EIGEN_REVERSE_H
-namespace Eigen {
+namespace StormEigen {
/** \class Reverse
* \ingroup Core_Module
@@ -206,6 +206,6 @@ void VectorwiseOp::reverseInPlace()
internal::vectorwise_reverse_inplace_impl::run(_expression().const_cast_derived());
}
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_REVERSE_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Select.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Select.h
index 79eec1b5b..4d7efd27d 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Select.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/Select.h
@@ -10,7 +10,7 @@
#ifndef EIGEN_SELECT_H
#define EIGEN_SELECT_H
-namespace Eigen {
+namespace StormEigen {
/** \class Select
* \ingroup Core_Module
@@ -157,6 +157,6 @@ DenseBase::select(const typename ElseDerived::Scalar& thenScalar,
derived(), ElseDerived::Constant(rows(),cols(),thenScalar), elseMatrix.derived());
}
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_SELECT_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/SelfAdjointView.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/SelfAdjointView.h
index 87e87ab3a..ec08e236e 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/SelfAdjointView.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/SelfAdjointView.h
@@ -10,7 +10,7 @@
#ifndef EIGEN_SELFADJOINTMATRIX_H
#define EIGEN_SELFADJOINTMATRIX_H
-namespace Eigen {
+namespace StormEigen {
/** \class SelfAdjointView
* \ingroup Core_Module
@@ -269,6 +269,6 @@ MatrixBase::selfadjointView()
return typename SelfAdjointViewReturnType::Type(derived());
}
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_SELFADJOINTMATRIX_H
diff --git a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/SelfCwiseBinaryOp.h b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/SelfCwiseBinaryOp.h
index 38185d9d7..8047d6ab2 100644
--- a/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/SelfCwiseBinaryOp.h
+++ b/resources/3rdparty/eigen-3.3-beta1/Eigen/src/Core/SelfCwiseBinaryOp.h
@@ -10,7 +10,7 @@
#ifndef EIGEN_SELFCWISEBINARYOP_H
#define EIGEN_SELFCWISEBINARYOP_H
-namespace Eigen {
+namespace StormEigen {
template
inline Derived& DenseBase::operator*=(const Scalar& other)
@@ -44,6 +44,6 @@ inline Derived& DenseBase::operator/=(const Scalar& other)
return derived();
}
-} // end namespace Eigen
+} // end namespace StormEigen
#endif // EIGEN_SELFCWISEBINARYOP_H